//
// Copyright(c) OPTOELECTRONICS CO., LTD. All rights reserved.
//

/*==========================================================================
Description:

	Barcode controls of hand-held terminal

Histroy:

	1.Version: 1.0.0  Date: 2008/05/13
		First Release

	2.Version: 1.0.1  Date: 2008/09/24
		Added: BCRGetLibraryVersion

	3.Version:1.0.2  Date: 2008/11/06
		Added:
		a. BCRSetVibratorState / BCRGetVibratorState
		b. BCRSetOutputMode / BCRGetOutputMode
		c. BCRSetTriggerKey / BCRGetTriggerKey
		d. BCRSetScanAngle / BCRGetScanAngle
		e. BCRTriggerPress / BCRTriggerRelease

	3.Version: 1.0.3  Date: 2009/01/19
		Added:
		a. BCRSetCodeOptions / BCRGetCodeOptions

	4.Version: 2.0.0 Date  2014/08/06
		Support 2D barcode reader
		
	5.Version: 2.0.1 Date: 2014/08/22
		Added:
		a. BCRSetSettingsEx / BCRGetSettingsEx
		b. BCRCO_MSI_PLESSEY_MOD11_MOD11 option

	6.Version: 2.0.2 Date: 2014/08/29
		Added:
		a. BCRSetTriggerRepeatMode / BCRGetTriggerRepeatMode

=============================================================================*/

#ifndef _BCRCTL_H_
#define _BCRCTL_H_


#ifdef __cplusplus
    #define BCRLIB extern "C"
#else
    #define BCRLIB extern
#endif 

//==========================================================================
//	BCRCTL Definitions
//==========================================================================
//
// Definition of BCR Maximum Length
//
#define BCR_MAX_COMMAND				256
#define BCR_MAX_PATH				256
#define BCR_MAX_DATA_LENGTH			2048
#define BCR_MAX_STRING				64			// Event name, version

// BCR Notification
#define WM_BCR_SCAN_NOTIFY			(WM_APP + 101)

// Definition of the status of read process
#define BCR_READ_NOT_READY			1
#define BCR_READ_GOOD				2
#define BCR_READ_NO_DATA			3
#define BCR_READ_TIMEOUT			4
#define BCR_READ_DISABLED			5
#define BCR_READ_ABORT				6

// Definition of Trigger key enable settings
#define BCR_TRIGGER_ENABLE			(TRUE)
#define BCR_TRIGGER_DISABLE			(FALSE)

// Definition of Trigger key settings
#define BCR_TRIGGER_SIDE			0x01
#define BCR_TRIGGER_CENTER			(0x01<<1)

// Definition of Buzzer volume settings
#define BCR_BUZZER_MUTE				0
#define BCR_BUZZER_VOLUME_LOW		1
#define BCR_BUZZER_VOLUME_MIDDLE	2
#define BCR_BUZZER_VOLUME_HIGH		3

// Definition of Output mode settings
#define BCR_OUTPUT_MODE_BUFFER		0x01
#define BCR_OUTPUT_MODE_KEYCODE		(0x01<<1)
#define BCR_OUTPUT_MODE_CLIPBOARD	(0x01<<2)

// Definition of the members of the BCR_CODE_OPTIONS struct
// (1)BCR_CODE_OPTIONS - dwMode
#define BCRCO_NORMAL_CODE39						1	// Code39
#define BCRCO_CODE39_FULLASCII					2	// Code39
#define BCRCO_CODE39_FULLASCII_IF_POSSIBLE		3	// Code39
#define BCRCO_ITALIAN_PHARM_ONLY				4	// Code39
#define BCRCO_ITALIAN_PHARM_IF_POSSIBLE			5	// Code39
#define BCRCO_CODABAR_NORMAL					6	// Codabar
#define BCRCO_ABC_CODE_ONLY						7	// Codabar
#define BCRCO_CX_CODE_ONLY						8	// Codabar
#define BCRCO_CODABAR_ABC_CX					9	// Codabar
#define BCRCO_TELEPEN_MODE_NUMERIC			  0xA 	// Telepen
#define BCRCO_TELEPEN_MODE_ASCII			  0xB 	// Telepen
#define BCRCO_EAN128_DISABLE				  0xC 	// Code128
#define BCRCO_EAN128_ENABLE_ONLY			  0xD 	// Code128
#define BCRCO_ENA128_ENABLE_IFPOSSIBLE		  0xE	// Code128

// (2)BCR_CODE_OPTIONS - dwCheckDigit
#define BCRCO_NOT_CHECK_DIGIT					1
#define BCRCO_CHECK_DIGIT						2
#define BCRCO_IATA_CHECK_FC_SN_ONLY				3	// IATA
#define BCRCO_IATA_CHECK_CPN_FC_SN				4	// IATA
#define BCRCO_IATA_CHECK_CPN_AC_FC_SN			5	// IATA
#define BCRCO_MSI_PLESSEY_1CD_MOD10				6	// MSI_Plessey
#define BCRCO_MSI_PLESSEY_MOD10_MOD10			7	// MSI_Plessey
#define BCRCO_MSI_PLESSEY_MOD10_MOD11			8	// MSI_Plessey
#define BCRCO_MSI_PLESSEY_MOD11_MOD10			9	// MSI_Plessey
#define BCRCO_CODE11_CHECK_1CD				  0xA	// Code11
#define BCRCO_CODE11_CHECK_2CD				  0xB	// Code11
#define BCRCO_CHECK_DIGIT_AUTO				  0xC	// Code11
#define BCRCO_MSI_PLESSEY_MOD11_MOD11		  0xD	// MSI_Plessey

// (3)BCR_CODE_OPTIONS - dwTransmitCD
#define BCRCO_UPC_NOLEADING0_TRANSMITCD			1	// UPC-A, UPC-E
#define BCRCO_UPC_NOLEADING0_NOT_TRANSMITCD		2	// UPC-A, UPC-E
#define BCRCO_UPC_LEADING0_TRANSMITCD			3	// UPC-A, UPC-E
#define BCRCO_UPC_LEADING0_NOT_TRANSMITCD		4	// UPC-A, UPC-E
#define BCRCO_NOT_TRANSMIT_CD					5
#define BCRCO_TRANSMIT_CD						6
#define BCRCO_TRANSMIT_CD1						7	// MSI_Plessey
#define BCRCO_TRANSMIT_CD1_CD2					8	// MSI_Plessey

// (4)BCR_CODE_OPTIONS - dwTransmitSTSP
#define BCRCO_NOT_TRANSMIT_STSP					1	// Code39
#define BCRCO_TRANSMIT_STSP						2	// Code39
#define BCRCO_STSP_ABCD							3	// Codabar
#define BCRCO_STSP_abcd							4	// Codabar
#define BCRCO_STSP_ABCD_TN_E					5	// Codabar
#define BCRCO_STSP_abcd_tn_e					6	// Codabar
#define BCRCO_STSP_DC1DC2DC3DC4					7	// Codabar

// (5)BCR_CODE_OPTIONS - dwSpecialOptions
#define BCRCO_DISABLE_CONCATENATION				1	// Code39, Code128, Code93
#define BCRCO_ENABLE_CONCATENATION				2	// Code39, Code128, Code93
#define BCRCO_DISABLE_CHECK_GAP					3	// Codabar
#define BCRCO_ENABLE_CHECK_GAP					4	// Codabar
#define BCRCO_DISABLE_SPACE_INSERTION			0xA	// Codabar
#define BCRCO_ENABLE_SPACE_INSERTION			0xB	// Codabar
#define BCRCO_D2OF5_NOT_CHECK_SPACE				5	// 2of5 and S-Code
#define BCRCO_D2OF5_CHECK_SPACE					6	// 2of5 and S-Code
#define BCRCO_NOT_TRANSMIT_AI					7	// GS1 Databar
#define BCRCO_TRANSMIT_AI						8	// GS1 Databar

// Definition of Read mode
#define BCR_READMODE_SINGLE			0
#define BCR_READMODE_MULTIPLE		1

// Definition of Read time
#define BCR_READ_INDEFINITELY		0xff

// Definition of Margin Check
#define BCR_MARGIN_CHECK_NO			0
#define BCR_MARGIN_CHECK_1OF7		1
#define BCR_MARGIN_CHECK_2OF7		2
#define BCR_MARGIN_CHECK_3OF7		3
#define BCR_MARGIN_CHECK_4OF7		4
#define BCR_MARGIN_CHECK_5OF7		5
#define BCR_MARGIN_CHECK_6OF7		6
#define BCR_MARGIN_CHECK_NORMAL		7

// Definition of Redundancy
#define BCR_REDUNDANCY_0			0
#define BCR_REDUNDANCY_1			1
#define BCR_REDUNDANCY_2			2
#define BCR_REDUNDANCY_3			3
#define BCR_REDUNDANCY_4			4
#define BCR_REDUNDANCY_5			5
#define BCR_REDUNDANCY_6			6
#define BCR_REDUNDANCY_7			7
#define BCR_REDUNDANCY_8			8

// Definition of Negative Barcode
#define BCR_BARCODE_POSITIVE		1
#define BCR_BARCODE_NEGATIVE		(0x01<<1)

// Definition of Scan angle
#define BCR_SCANANGLE_NORMAL		0
#define BCR_SCANANGLE_NARROW		1

// Definition of Camera options
#define BCR_CAMERA_LED_MODE_ENABLE	1
#define BCR_CAMERA_LED_MODE_DISABLE	2
#define BCR_CAMERA_LED_MODE_ALTERNATIVE			3
#define BCR_CAMERA_LED_MODE_MIRROR_REFLECTION	4

#define BCR_AIMER_MODE_ENABLE		1
#define BCR_AIMER_MODE_DISABLE		2


//==========================================================================
//	BCRCTL Enumerations
//==========================================================================
//
// The value of BCR module type
//
typedef enum _BCR_MODULE_TYPE
{
	BCR_MODULE_TYPE_UNKNOWN = 0,
	BCR_MODULE_TYPE_MDL,
	BCR_MODULE_TYPE_MDI,
	BCR_MODULE_TYPE_1D = 1,
	BCR_MODULE_TYPE_2D = 2,
} BCR_MODULE_TYPE;

//
// The value of the Symbology ID
//
typedef enum _SYMBOLOGY_ID
{
	SYMBOLOGY_UPCA = 1,
	SYMBOLOGY_UPCE,
	SYMBOLOGY_EAN8,
	SYMBOLOGY_EAN13,
	SYMBOLOGY_Code39,
	SYMBOLOGY_Codabar,
	SYMBOLOGY_2of5andSCode,
	SYMBOLOGY_KoreanPostalAuthority,
	SYMBOLOGY_IATA,
	SYMBOLOGY_MSIPlessey,
	SYMBOLOGY_Telepen,
	SYMBOLOGY_UKPlessey,
	SYMBOLOGY_Code128andEAN128,
	SYMBOLOGY_Code93,
	SYMBOLOGY_Code11,
	SYMBOLOGY_GS1DataBar,
	SYMBOLOGY_Composite,
	SYMBOLOGY_PDF417,
	SYMBOLOGY_MicroPDF417,
	MAX_CODES_OPTIONS = SYMBOLOGY_MicroPDF417,
	SYMBOLOGY_NODATA = 0xFFFF
} SYMBOLOGY_ID;
#define MAX_CODES MAX_CODES_OPTIONS


//==========================================================================
//	BCRCTL Structures
//==========================================================================
//
//Struct of Code Options
//
typedef struct _BCR_READABLE_CODES
{
	DWORD dwSize;  //Specifies the structure length, in bytes
	DWORD dwValidFileds;//Specifies the number of readable codes.

	//bits 0~7
	DWORD BCR_UPC:1;
	DWORD BCR_UPC_2:1;
	DWORD BCR_UPC_5:1;
	DWORD BCR_EAN:1;
	DWORD BCR_EAN_2:1;
	DWORD BCR_EAN_5:1;
	DWORD BCR_CODE39:1;
	DWORD BCR_TRIOPTIC:1;

	//bits 8~15
	DWORD BCR_CODABAR:1;
	DWORD BCR_INDUSTRIAL_2of5:1;
	DWORD BCR_INTERLEAVED_2of5:1;
	DWORD BCR_SCODE:1;
	DWORD BCR_MATRIX_2of5:1;
	DWORD BCR_CHINESE_POST_MATRIX:1;
	DWORD BCR_KOREAN_POSTAL_AUTHORITY:1;
	DWORD BCR_IATA:1;

	 //bits 16~23
	DWORD BCR_MSI_PLESSEY:1;
	DWORD BCR_TELEPEN:1;
	DWORD BCR_UK_PLESSEY:1;
	DWORD BCR_CODE128:1;
	DWORD BCR_CODE93:1;
	DWORD BCR_CODE11:1;
	DWORD BCR_RSS_14:1;
	DWORD BCR_RSS_LIMITED:1;

	//bits 24~31
	DWORD BCR_RSS_EXPANDED:1;
	DWORD BCR_DATAMATRIX_ECC000:1;
	DWORD BCR_DATAMATRIX_ECC200:1;
	DWORD BCR_AZTEC:1;
	DWORD BCR_AZTEC_RUNES:1;
	DWORD BCR_QR_CODE:1;
	DWORD BCR_MAXICODE:1;
	DWORD BCR_PDF417:1;

	//bits 32~39
	DWORD BCR_MICRO_PDF417:1;
	DWORD BCR_COMPOSITE_GS1:1;
	DWORD BCR_COMPOSITE_EAN_UPA:1;
	DWORD BCR_CODABLOCK_F:1;
	DWORD BCR_MICRO_QR:1;
	DWORD BCR_CHINESE_SENSIBLE_CODE:1;
	DWORD BCR_INTELLIGENT_MAIL_BARCODE:1;
	DWORD BCR_POSTNET:1;

	//bits 40~44
	DWORD BCR_JPN_CUSTOMER_BARCODE:1;
	DWORD BCR_PLANET:1;
	DWORD BCR_NETHERLANDS_KIX_CODE:1;
	DWORD BCR_UK_POSTAL:1;
	DWORD BCR_AUSTRALIAN_POSTAL:1;
} BCR_READABLE_CODES, *LPBCR_READABLE_CODES;

//
// Struct of Code Options
//
typedef struct _BCR_CODE_OPTIONS
{
    SYMBOLOGY_ID Symbology;
    DWORD dwMode;
    DWORD dwCheckDigit;
    DWORD dwTransmitCD;
    DWORD dwTransmitSTSP;
    DWORD dwSpecialOptions;
    DWORD dwReserved;
} BCR_CODE_OPTIONS, *PBCR_CODE_OPTIONS;

//
//Struct of Read Options
//
typedef struct _BCR_READ_OPTIONS
{
	DWORD dwReadMode;
	DWORD dwReadTime;
	DWORD dwMargin;
	DWORD dwRedundancy;
	DWORD dwNegativeBarcode;
	DWORD dwScanAngle;
} BCR_READ_OPTIONS, *PBCR_READ_OPTIONS;

typedef struct _BCR_READ_OPTIONS_2D
{
	BOOL  CentralReading;
	DWORD dwCollectiveLabelNumber;
	BOOL  CapDecParallelMode;
	BOOL  TriggerRepeat;
	DWORD Reserved;
} BCR_READ_OPTIONS_2D, *PBCR_READ_OPTIONS_2D;

typedef struct _BCR_CAMERA_OPTIONS
{
	DWORD dwCameraLEDMode;
	DWORD dwAimerMode;
	DWORD Reserved1;
	DWORD Reserved2;
} BCR_CAMERA_OPTIONS, *PBCR_CAMERA_OPTIONS;

//
//Struct of General Settings
//
typedef struct _BCR_SETTINGS
{
	DWORD dwPowerStatus;
	DWORD dwTriggerKeyState;
	DWORD dwTriggerKey;
	DWORD dwOutputMode;
	DWORD dwBuzzerVolume;
	TCHAR szBeepFile[BCR_MAX_PATH];
	DWORD dwVibratorState;
	DWORD dwSuffixChar;
	BCR_READ_OPTIONS ReadOptions;
	BCR_READABLE_CODES ReadableCode;
	BCR_CODE_OPTIONS CodeOptions[MAX_CODES];
	TCHAR szAdditonalCommands[BCR_MAX_PATH];
} BCR_SETTINGS, *LPBCR_SETTINGS;

typedef struct _BCR_SETTINGS_EX
{
	DWORD dwSize;
	DWORD dwPowerStatus;
	DWORD dwTriggerKeyState;
	DWORD dwTriggerKey;
	DWORD dwOutputMode;
	DWORD dwBuzzerVolume;
	TCHAR szBeepFile[BCR_MAX_PATH];
	DWORD dwVibratorState;
	DWORD dwSuffixChar;
	BCR_READ_OPTIONS ReadOptions;
	BCR_READABLE_CODES ReadableCode;
	BCR_CODE_OPTIONS CodeOptions[MAX_CODES];
	TCHAR szAdditonalCommands[BCR_MAX_PATH];
	BCR_READ_OPTIONS_2D ReadOptions2D;
	BCR_CAMERA_OPTIONS CameraOptions;
} BCR_SETTINGS_EX, *LPBCR_SETTINGS_EX;

//==========================================================================
//	BCRCTL Functions
//==========================================================================
//
//--------------------------------------------------------------------------
//	Power On/Off and Read barcode
//--------------------------------------------------------------------------
//
// BCRGetPowerStatus
// Retrieve the power status of the barcode reader.
//
BCRLIB BOOL BCRGetPowerStatus(BOOL* pbPowerStatus);
typedef BOOL (*PFN_BCRGetPowerStatus)(BOOL* pbPowerStatus);

//
// BCRPowerOn
// Turn on the power of the barcode reader.
//
BCRLIB BOOL BCRPowerOn(VOID);
typedef BOOL (*PFN_BCRPowerOn)(VOID);

//
// BCRPowerOff
// Turn off the power of the barcode reader.
//
BCRLIB BOOL BCRPowerOff(VOID);
typedef BOOL (*PFN_BCRPowerOff)(VOID);

//
// BCRStartScan
// Simulate a software trigger for the decoder.
//
BCRLIB BOOL BCRStartScan(VOID);
typedef BOOL (*PFN_BCRStartScan)(VOID);

//
// BCRAbortScan
// Abort the process of a barcode scanning.
//
BCRLIB BOOL BCRAbortScan(VOID);
typedef BOOL (*PFN_BCRAbortScan)(VOID);

//
// BCRTriggerPress
// Simulate a hardware trigger press.
//
BCRLIB BOOL BCRTriggerPress(VOID);
typedef BOOL (*PFN_BCRTriggerPress)(VOID);

//
// BCRTriggerRelease
// Simulate a hardware trigger release.
//
BCRLIB BOOL BCRTriggerRelease(VOID);
typedef BOOL (*PFN_BCRTriggerRelease)(VOID);

//
// BCRGetBarcode
// Retrieve the barcode data and the information.
//
BCRLIB BOOL BCRGetBarcode(BYTE* pDecodeData, DWORD* lpdwLength, DWORD* lpdwFlag);
typedef BOOL (*PFN_BCRGetBarcode)(BYTE* pDecodeData, DWORD* lpdwLength, DWORD* lpdwFlag);

//
// BCRClearBuffer
//Clear the barcode data buffer in the BCR driver.
//
BCRLIB BOOL BCRClearBuffer(VOID);
typedef BOOL (*PFN_BCRClearBuffer)(VOID);

//
// BCRGetReadNotification
// Retrieve information about the read notification.
//
BCRLIB BOOL BCRGetReadNotification(UINT *pReadDataMsg, LPTSTR lpReadDataEventName);
typedef BOOL (*PFN_GetReadNotification)(UINT *pReadDataMsg, LPTSTR lpReadDataEventName);

//
// BCRGetLastReadEventStatus
// Retrieve the status of the barcode scanning.
//
BCRLIB BOOL BCRGetLastReadEventStatus(DWORD* lpdwStatus);
typedef BOOL (*PFN_BCRGetLastReadEventStatus)(DWORD* lpdwStatus);

//--------------------------------------------------------------------------
// General Settings of the Barcode Reader
//--------------------------------------------------------------------------
//
// BCRGetTriggerKeyStatus
// Retrieve the trigger key status of the device.
//
BCRLIB BOOL BCRGetTriggerKeyStatus(DWORD* lpdwTriggerKeyState);
typedef BOOL (*PFN_BCRGetTriggerKeyStatus)(DWORD* lpdwTriggerKeyState);

//
// BCREnableTriggerKey
// Enable the trigger key of the device.
//
BCRLIB BOOL BCREnableTriggerKey(VOID);
typedef BOOL (*PFN_BCREnableTriggerKey)(VOID);

//
// BCRDisableTriggerKey
// Disable the trigger key of the device.
//
BCRLIB BOOL BCRDisableTriggerKey(VOID);
typedef BOOL (*PFN_BCRDisableTriggerKey)(VOID);

//
// BCRGetTriggerKey
// Get the information of valid triggers.
//
BCRLIB BOOL BCRGetTriggerKey(DWORD* lpTriggers);
typedef BOOL (*PFN_BCRGetTriggerKey)(DWORD* lpTriggers);

//
// BCRSetTriggerKey
// Set valid triggers.
//
BCRLIB BOOL BCRSetTriggerKey(DWORD dwTriggers);
typedef BOOL (*PFN_BCRSetTriggerKey)(DWORD dwTriggers);

//
// BCRGetOutputMode
// Retrieve the information about the barcode output mode.
//		BCR_OUTPUT_MODE_BUFFER
//		BCR_OUTPUT_MODE_KEYCODE
//		BCR_OUTPUT_MODE_CLIPBOARD
//
BCRLIB BOOL BCRGetOutputMode(DWORD* lpOutputMode);
typedef BOOL (*PFN_BCRGetOutputMode)(DWORD* lpOutputMode);

//
// BCRSetOutputMode
// Set barcode output mode.
//
BCRLIB BOOL BCRSetOutputMode(DWORD dwOutputMode);
typedef BOOL (*PFN_BCRSetOutputMode)(DWORD dwOutputMode);

//
// BCRGetBuzzerStatus
// Retrieve the buzzer status of the barcode reader.
//
BCRLIB BOOL BCRGetBuzzerStatus(DWORD* lpdwBuzzerVolume, LPTSTR lpBeepFile);
typedef BOOL (*PFN_BCRGetBuzzerStatus)(DWORD* lpdwBuzzerVolume,LPCTSTR lpBeepFile);

//
// BCRSetBuzzerStatus
// Set the beep option of the barcode reader.
//
BCRLIB BOOL BCRSetBuzzerStatus(DWORD dwBuzzerVolume, LPCTSTR lpBeepFile);
typedef BOOL (*PFN_BCRSetBuzzerStatus)(DWORD dwBuzzerVolume,LPCTSTR lpBeepFile);

//
// BCRGetVibratorState
// Retrieve the vibrator state of the barcode reader.
//
BCRLIB BOOL BCRGetVibratorState(DWORD* lpVibratorTime);
typedef BOOL (*PFN_BCRGetVibratorState)(DWORD* lpVibratorTime);

//
// BCRSetVibratorState
// Enables or disable the vibrator of the barcode reader,
// and set the vibration time.
//
BCRLIB BOOL BCRSetVibratorState(DWORD dwVibratorTime);
typedef BOOL (*PFN_BCRSetVibratorState)(DWORD dwVibratorTime);

//
// BCRGetSettings
// Retrieve the all settings information of the barcode reader,
// include the basic settings and decoder option settings.
// (Not include 2D-options: for H-15AJ compatibility)
//
BCRLIB BOOL BCRGetSettings(BCR_SETTINGS* lpSettingsData);
typedef BOOL (*PFN_BCRGetSettings)(BCR_SETTINGS* lpSettingsData);

//
// BCRSetSettings
// Restore the all settings to the barcode reader,
// include the basic settings and decoder option settings.
// (Not include 2D-options: for H-15AJ compatibility)
//
BCRLIB BOOL BCRSetSettings(BCR_SETTINGS* lpSettingsData);
typedef BOOL (*PFN_BCRSetSettings)(BCR_SETTINGS* lpSettingsData);

//
// BCRGetSettingsEx
// Retrieve the all settings information of the barcode reader,
// include the basic settings and decoder option (include 2D-option) settings.
//
BCRLIB BOOL BCRGetSettingsEx(BCR_SETTINGS_EX* lpSettingsDataEx);
typedef BOOL (*PFN_BCRGetSettingsEx)(BCR_SETTINGS* lpSettingsDataEx);

//
// BCRSetSettingsEx
// Restore the all settings to the barcode reader,
// include the basic settings and decoder option (include 2D-option) settings.
//
BCRLIB BOOL BCRSetSettingsEx(BCR_SETTINGS_EX* lpSettingsDataEx);
typedef BOOL (*PFN_BCRSetSettingsEx)(BCR_SETTINGS* lpSettingsDataEx);

//
// BCRGetDefault
// Retrieve the all default settings of the barcode reader,
//
BCRLIB BOOL BCRGetDefault(BCR_SETTINGS_EX* pSettings);

//
// BCRSetDefault
// Set all settings of the barcode reader to the default.
//
BCRLIB BOOL BCRSetDefault(VOID);
typedef BOOL (*PFN_BCRSetDefault)(VOID);

//--------------------------------------------------------------------------
// Decoder Settings
//--------------------------------------------------------------------------
//-----------------------
// 1. Code Options
//-----------------------
//
// BCRGetReadableCode
// Retrieve information about readable code symbology.
//
BCRLIB BOOL BCRGetReadableCode(LPBCR_READABLE_CODES lpBCRSymbology);
typedef BOOL (*PFN_BCRGetReadableCode)(LPBCR_READABLE_CODES lpBCRSymbology);

//
// BCRSetReadableCode
// Enable or disable for scanning each barcode symbology.
//
BCRLIB BOOL BCRSetReadableCode(BCR_READABLE_CODES BCRSymbology);
typedef BOOL (*PFN_BCRSetReadableCode)(BCR_READABLE_CODES BCRSymbology);

//
// BCRGetCodeOptions
// Get the bar code specific option.
//
BCRLIB BOOL BCRGetCodeOptions(PBCR_CODE_OPTIONS pCodeOption);
typedef BOOL (*PFN_BCRGetCodeOptions)(PBCR_CODE_OPTIONS pCodeOption);

//
// BCRSetCodeOptions
// Set the bar code specific option.
//
BCRLIB BOOL BCRSetCodeOptions(PBCR_CODE_OPTIONS pCodeOption);
typedef BOOL (*PFN_BCRSetCodeOptions)(PBCR_CODE_OPTIONS pCodeOption);

//-----------------------
// 2. String Options
//-----------------------
//
// BCRGetSuffixChar
// Retrieve the suffix which is one of the 128 ASCII characters.
//
BCRLIB BOOL BCRGetSuffixChar(DWORD* lpSuffix);
typedef BOOL (*PFN_BCRGetSuffixChar)(DWORD* lpSuffix);

//
// BCRSetSuffixChar
// Set the suffix that will be transmitted follow the barcode data.
// The character should be one of the 128 ASCII characters.
//
BCRLIB BOOL BCRSetSuffixChar(DWORD dwSuffix);
typedef BOOL (*PFN_BCRSetSuffixChar)(DWORD dwSuffix);

//-----------------------
// 3. Read Options
//-----------------------
//
// BCRGetReadMode
// Retrieve information about the read mode.
//
BCRLIB BOOL BCRGetReadMode(DWORD* lpdwReadMode);
typedef BOOL (*PFN_BCRGetReadMode)(DWORD* lpdwReadMode);

//
// BCRSetReadMode
// Set the single read mode or multiple read mode.
//
BCRLIB BOOL BCRSetReadMode(DWORD dwReadMode);
typedef BOOL (*PFN_BCRSetReadMode)(DWORD dwReadMode);

//
// BCRGetReadTimeOption
// Retrieve information about read time.
//
BCRLIB BOOL BCRGetReadTimeOption(DWORD* lpdwReadTime);
typedef BOOL (*PFN_BCRGetReadTimeOption)(DWORD* lpdwReadTime);

//
// BCRSetReadTiemOption
// Set the read time option.
//
BCRLIB BOOL BCRSetReadTimeOption(DWORD dwReadTime);
typedef BOOL (*PFN_BCRSetReadTimeOption)(DWORD dwReadTime);

//
// BCRGetMarginCheck
// Retrieve information about margin check.
//
BCRLIB BOOL BCRGetMarginCheck(DWORD* lpMargin);
typedef BOOL (*PFN_BCRGetMarginCheck)(DWORD* lpMargin);

//
// BCRSetMarginCheck
// Set the quiet zone option for the reader (margin check).
//
BCRLIB BOOL BCRSetMarginCheck(DWORD dwMargin);
typedef BOOL (*PFN_BCRSetMarginCheck)(DWORD dwMargin);

//
// BCRGetRedundancy
// Retrieve information about the redundancy count.
//
BCRLIB BOOL BCRGetRedundancy(DWORD* lpRedundancyCount);
typedef BOOL (*PFN_BCRGetRedundancy)(DWORD* lpRedundancyCount);

//
// BCRSetRedundancy
// Set the redundancy count.
//
BCRLIB BOOL BCRSetRedundancy(DWORD dwRedundancyCount);
typedef BOOL (*PFN_BCRSetRedundancy)(DWORD dwRedundancyCount);

//
// BCRGetNegativeBarcode
// Retrieve information about reading the negative barcode.
//
BCRLIB BOOL BCRGetNegativeBarcode(DWORD* lpNegativeFlag);
typedef BOOL (*PFN_BCRGetNegativeBarcode)(DWORD* lpNegativeFlag);

//
// BCRSetNegativeBarcode
// Enable the reader to read a negative barcode.
//
BCRLIB BOOL BCRSetNegativeBarcode(DWORD dwNegativeFlag);
typedef BOOL (*PFN_BCRSetNegativeBarcode)(DWORD dwNegativeFlag);

//
// BCRGetScanAngle
// Retrieve information about the laser scan angle, normal or narrow.
//
BCRLIB BOOL BCRGetScanAngle(DWORD* lpScanAngle);
typedef BOOL (*PFN_BCRGetScanAngle)(DWORD* lpScanAngle);

//
// BCRSetScanAngle
// Set the laser scan angle, normal or narrow.
//
BCRLIB BOOL BCRSetScanAngle(DWORD dwScanAngle);
typedef BOOL (*PFN_BCRSetScanAngle)(DWORD dwScanAngle);

//-----------------------
// 4. General Command
//-----------------------
//
// BCRGetCommand
// Retrieve the last commands sent to the barcode module.
//
BCRLIB BOOL BCRGetCommand(LPTSTR lpOptionsString);
typedef BOOL (*PFN_BCRGetCommand)(LPTSTR lpOptionsString);

//
// BCRSendCommand
// Send the universal command to the barcode decoder.
//
BCRLIB BOOL BCRSendCommand(LPTSTR lpOptionsString);
typedef BOOL (*PFN_BCRSendCommand)(LPTSTR lpOptionsString);

//--------------------------------------------------------------------------
// Functions for 2D barcode reader
//--------------------------------------------------------------------------
//
// BCRGetCameraLEDMode
// Retrieves the information about the Mode of the Camera LED.
//
BCRLIB BOOL BCRGetCameraLEDMode(DWORD* lpdwLedMode);

//
// BCRSetCameraLEDMode
// Set the Mode of the Camera LED as:
//		BCR_CAMERA_LED_MODE_ENABLE
//		BCR_CAMERA_LED_MODE_DISABLE
//
BCRLIB BOOL BCRSetCameraLEDMode(DWORD dwLedMode);

//
// BCRGetCameraAimerMode
// Retrieves the information about the Mode of the aimer LED.
//
BCRLIB BOOL BCRGetCameraAimerMode(DWORD* lpdwAimerMode);

//
// BCRSetCameraAimerMode
// Set the Mode of the Aimer LED as:
//		BCR_AIMER_MODE_ENABLE
//		BCR_AIMER_MODE_DISABLE
//
BCRLIB BOOL BCRSetCameraAimerMode(DWORD dwAimerMode);

//
// BCRGetCollectiveLabelNumber
// Retrieves the number of collective label.
//
BCRLIB BOOL BCRGetCollectiveLabelNumber(DWORD* dwNumber);

//
// BCRSetCollectiveLabelNumber
// Set the number of collective label.
//
BCRLIB BOOL BCRSetCollectiveLabelNumber(DWORD dwNumber);

//
// BCRGetCentralReadingMode
// Retrieves the information about the central reading.
//
BCRLIB BOOL BCRGetCentralReadingMode(BOOL* pbEnabled);

//
// BCRSetCentralReadingMode
// Set the central reading or not.
//
BCRLIB BOOL BCRSetCentralReadingMode(BOOL bEnabled);

//
// BCRGetCaptureDecodeParallelMode
// Retrieves the information that Capture and Decode is a parallel mode.
//
BCRLIB BOOL BCRGetCaptureDecodeParallelMode(BOOL* pbEnabled);

//
// BCRSetCaptureDecodeParallelMode
// Set that Capture is parallel with Decode or not.
//
BCRLIB BOOL BCRSetCaptureDecodeParallelMode(BOOL bEnabled);

//
// BCRGetTriggerRepeatMode
// Retrieves the information about the Trigger repeat mode.
//
BCRLIB BOOL BCRGetTriggerRepeatMode(BOOL* bTargetScan);

//
// BCRSetTriggerRepeatMode
// Set the Trigger repeat mode or not.
//
BCRLIB BOOL BCRSetTriggerRepeatMode(BOOL bTargetScan);

//
// BCRTakeSnapShot
// Take a snap shot.
//
BCRLIB BOOL BCRTakeSnapShot(LPTSTR lpFileName);

//--------------------------------------------------------------------------
// Version Information
//--------------------------------------------------------------------------
//
// BCRGetModuleType
// Retrieves the information about the module type
//  (Laser barcode reader or CMOS barcode reader).
//
BCRLIB BOOL BCRGetModuleType(DWORD* lpdwModuleType);

//
// BCRGetFirmwareVersion
// Retrieve the information about the module firmware.
//
BCRLIB BOOL BCRGetFirmwareVersion(LPTSTR lpFirmwareVersion);
typedef BOOL (*PFN_BCRGetFirmwareVersion)(LPTSTR lpFirmwareVersion);

//
// BCRGetDriverVersion
// Retrieve the information about the driver version.
//
BCRLIB BOOL BCRGetDriverVersion(LPTSTR lpDriverVersion);
typedef BOOL (*PFN_BCRGetDriverVersion)(LPTSTR lpDriverVersion);

//
// BCRGetLibraryVersion
// Retrieve the information about the bcrctl library.
//
BCRLIB BOOL BCRGetLibraryVersion(LPTSTR lpLibraryVersion);
typedef BOOL (*PFN_BCRGetLibraryVersion) (LPTSTR lpLibraryVersion);

#endif 