#ifndef _SYSCTL_H
#define _SYSCTL_H

#ifdef __cplusplus
extern "C"
{
#endif

#define SYS_POWER_BATTERY_MODE   0x01

#define SYS_POWER_EXTERNAL_MODE  (0x01<<1)


//======= Settings for keypad ========

#define NUMERICAL_KEY_MODE  0

#define ALPHA_KEY_MODE    (NUMERICAL_KEY_MODE+1)

#define FUNC_KEY_MODE     (NUMERICAL_KEY_MODE+2)

#define SYS_KEY_F1 1
#define SYS_KEY_F2 2
#define SYS_KEY_F3 3
#define SYS_KEY_F4 4
#define SYS_KEY_F5 5
#define SYS_KEY_F6 6
#define SYS_KEY_F7 7
#define SYS_KEY_F8 8
#define SYS_KEY_Q1 9
#define SYS_KEY_Q2 10

#define SYS_KEY_FN_F1  11
#define SYS_KEY_FN_F2  12
#define SYS_KEY_FN_F3  13
#define SYS_KEY_FN_F4  14
#define SYS_KEY_FN_Q1  15
#define SYS_KEY_FN_Q2  16

#define SYS_KEY_FN_1         17      
#define SYS_KEY_FN_2         18
#define SYS_KEY_FN_3         19 
#define SYS_KEY_FN_4         20
#define SYS_KEY_FN_5         21
#define SYS_KEY_FN_6         22
#define SYS_KEY_FN_7         23
#define SYS_KEY_FN_8         24
#define SYS_KEY_FN_9         25
#define SYS_KEY_FN_0         26
#define SYS_KEY_FN_PERIOD    27
#define SYS_KEY_FN_MINUS     28

#define SYS_KEY_ACTION (0x01)

#define SYS_KEY_ENT    (0x02)


//======= Settings for function key  =======

#define SYS_FN_SIP             TEXT("FN_SIP")

#define SYS_FN_CUT             TEXT("FN_CUT")

#define SYS_FN_COPY            TEXT("FN_COPY")

#define SYS_FN_PASTE           TEXT("FN_PASTE")

#define SYS_FN_VOLUME_UP       TEXT("FN_VOLUME_UP")

#define SYS_FN_VOLUME_DOWN     TEXT("FN_VOLUME_DOWN")

#define SYS_FN_BACKLIGHT_UP    TEXT("FN_BACKLIGHT_UP")

#define SYS_FN_BACKLIGHT_DOWN  TEXT("FN_BACKLIGHT_DOWN")

//======= Settings for backlight ========


//backlight levels 

#define SYS_BACKLIGHT_LEVEL_MINIMUM 0

#define SYS_BACKLIGHT_LEVEL_1       1

#define SYS_BACKLIGHT_LEVEL_2       2

#define SYS_BACKLIGHT_LEVEL_3       3

#define SYS_BACKLIGHT_LEVEL_4       4

#define SYS_BACKLIGHT_LEVEL_MAXIMUM 5

//backlight timer 

#define BACKLIGHT_TIMEOUT_INDEFINITELY 0

#define BACKLIGHT_TIMEOUT_TEN_SEC      10    //Battery mode only

#define BACKLIGHT_TIMEOUT_THIRTY_SEC   30    //Battery mode only

#define BACKLIGHT_TIMEOUT_ONE_MIN      60

#define BACKLIGHT_TIMEOUT_TWO_MIN      120

#define BACKLIGHT_TIMEOUT_THREE_MIN    180

#define BACKLIGHT_TIMEOUT_FOUR_MIN     240

#define BACKLIGHT_TIMEOUT_FIVE_MIN     300

#define BACKLIGHT_TIMEOUT_SIX_MIN      360   //external power mode only

#define BACKLIGHT_TIMEOUT_SEVEN_MIN    420   //external power mode only

#define BACKLIGHT_TIMEOUT_EIGHT_MIN    480   //external power mode only

#define BACKLIGHT_TIMEOUT_NINE_MIN     540   //external power mode only

#define BACKLIGHT_TIMEOUT_TEN_MIN      600   //external power mode only


//Settings for power 

#define SYS_WLAN_POWER_OFF (0x00)

#define SYS_WLAN_POWER_ON  (0x01)

#define SYS_BT_POWER_OFF   (0x00)

#define SYS_BT_POWER_ON    (0x01)


//======= Settings for boot programs ==========
#define  COLD_BOOT_INIT       0
#define  WARM_BOOT_INIT       1
#define  SLEEP_RESUME_INIT    2


//======= Settings for system ========

#define SYSTEM_BATTERY_HIGH              0x01

#define SYSTEM_BATTERY_LOW               0x02

#define SYSTEM_BATTERY_CRITICAL          0x04

#define SYSTEM_BATTERY_STATE_UNKNOWN     0xff


//======= Settings for power schemes ==========



#define SUSPEND_TIME_ONE_MIN       1

#define SUSPEND_TIME_TWO_MIN       2 

#define SUSPEND_TIME_THREE_MIN     3 // battery power mode only

#define SUSPEND_TIME_FOUR_MIN      4 // battery power mode only

#define SUSPEND_TIME_FIVE_MIN      5

#define SUSPEND_TIME_TEN_MIN      10

#define SUSPEND_TIME_FIFTEEN_MIN  15 // external power mode only

#define SUSPEND_TIME_THIRTY_MIN   30 

#define SUSPEND_TIME_INDEFINITELY  0 // Never auto-suspend

//======= Settings of power down mode ============

#define SYS_POWERON_RESUME   (0x00)

#define SYS_POWERON_RESET    (0x01)

//======= WLAN APIs Parameter ====================

#define SYS_WLAN_STATUS_CONNECTED 		(0x01)

#define SYS_WLAN_STATUS_DISCONNECTED  	(0x02)

#define SYS_WLAN_STATUS_UNAVAILABLE   	(0x03)

#define SYS_WLAN_REGULATORY_US			(0x10)

#define SYS_WLAN_REGULATORY_CANADA    	(0x20)

#define SYS_WLAN_REGULATORY_EU			(0x30)

#define SYS_WLAN_REGULATORY_SPAIN		(0x31)

#define SYS_WLAN_REGULATORY_FRANCE		(0x32)

#define SYS_WLAN_REGULATORY_JAPAN		(0x40)

typedef struct _SYS_WLAN_PROFILE_DATA{

	TCHAR	ProfileName[256];
	TCHAR 	SSID[32];
	INT 	NetworkMode;
	TCHAR 	DSChannel;
	TCHAR 	TXRate;
	INT		PowerMode;
	BOOL	UsePrivacy;
	INT		WPAEncryptionStatus;
	INT		WPAAuthenticationMode;
	BOOL	WPAUseUniqueKey;
	BOOL	Is8021XEnabled;
	BOOL	isWPAEnabled;
	INT		DefaultKeyID;
	INT		KeySize;
	TCHAR 	Key0[128];
	INT		Key0Type;
	TCHAR 	Key1[128];
	INT		Key1Type;
	TCHAR 	Key2[128];
	INT		Key2Type;
	TCHAR 	Key3[128];
	INT		Key3Type;
	INT		WPAType;
	TCHAR	WPAUniqueKey[128];
	TCHAR	WPAKey[128];
	TCHAR	UserName[256];
	TCHAR 	Password[128];
	TCHAR 	CertificateName[256];

} SYS_WLAN_PROFILE_DATA;

//system wakeup sources
#define SYS_WAKESOURCE_USB_CRADLE (0x01)

//======= LED control API parameters =============

#define SYS_LED_BLUE		1

#define SYS_LED_GREEN		2

#define SYS_LED_RED			3

//=====================================
//=         Device Information        =
//=====================================

BOOL SysGetModelName(LPTSTR lpszModelName);

BOOL SysGetFirmwareVersion (LPTSTR lpszFWVersion);

BOOL SysGetSoftwareVersion (LPTSTR lpszSWVersion);

BOOL SysGetConfigNumber(LPTSTR lpszConfigNumber);

BOOL SysGetSerialNumber(LPTSTR lpszSerialNumber);

BOOL SysGetLibraryVersion(LPTSTR lpLibraryVersion);

void SysGetMemorySize (PDWORD lpROMSize,PDWORD lpRAMSize);


//=====================================
//=         Keypad Controls           =
//=====================================

BOOL SysGetKBDInputMode(PBYTE lpdwInputMode);

BOOL SysSetKBDInputMode(BYTE lwInputMode);

BOOL SysGetKeypadState(DWORD dwVKCode, PBOOL lpdwLockState);

BOOL SysSetKeypadState(DWORD dwVKCode, BOOL dwLockState);

BOOL SysSetAlternateKeyCode(DWORD dwKey, BOOL bAlternate);

BOOL SysGetAlternateKeyCode(DWORD dwKey, BOOL* bAlternate);


//=====================================
//=         Function Key Controls     =
//=====================================

BOOL SysGetFunctionKeyPrograms(DWORD dwFuncKey,LPCTSTR  lpszAppName,LPCTSTR lpszParameters);

BOOL SysSetFunctionKeyPrograms(DWORD dwFuncKey,LPCTSTR  lpszAppName,LPCTSTR lpszParameters);

BOOL SysGetFunctionKeySettingState(PBOOL lpState);

BOOL SysSetFunctionKeySettingState(BOOL dwState);


//=====================================
//=         Backlight Controls        =
//=====================================
BOOL SysGetBacklightLevel(PBYTE lpdwLevel);

BOOL SysSetBacklightLevel(BYTE dwLevel);

BOOL SysGetBacklightTimeout(DWORD dwPowerMode,LPDWORD lpdwBacklightTimeout);

BOOL SysSetBacklightTimeout(DWORD dwPowerMode,DWORD dwBacklightTimeout);


//=====================================
//=       WLAN Controls               =
//=====================================

BOOL SysSetWLANPower(DWORD dwPowerStatus);

BOOL SysGetWLANPower(LPDWORD lpdwPowerStatus);

BOOL SysGetWLANPHYAddress(LPTSTR  lpszPhyAddr);

BOOL SysGetWLANSignalStrength(PBYTE  lpSignalStrength);

BOOL SYSGetWlan_Connection(void);

BOOL SysGetWLANConnectStatus(LPDWORD lpStatus);

BOOL SysGetWLANSignalLevel(LPDWORD lpLevel);

BOOL SysSetWLANRegulatory(DWORD dwRegulatory);

BOOL SysGetWLANRegulatory(LPDWORD dwRegulatory);

BOOL SysWLANGetProfileNumber(LPDWORD lpProfileNumber);

BOOL SysWLANGetProfileData(DWORD dwIndex, SYS_WLAN_PROFILE_DATA* lpProfileData);

BOOL SysWLANSetProfileData(DWORD dwIndex, SYS_WLAN_PROFILE_DATA* lpProfileData);

BOOL SysWLANGetCurrentProfile(LPDWORD lpIndex, SYS_WLAN_PROFILE_DATA* lpProfileData);

BOOL SysWLANSetCurrentProfile(DWORD dwIndex);

BOOL SysWLANDeleteProfile(DWORD dwProfileIndex);

BOOL SysWLANAddProfile(SYS_WLAN_PROFILE_DATA* lpProfileData);

//=====================================
//=       Bluetooth Controls          =
//=====================================

BOOL SysSetBluetoothPower(DWORD dwPowerStatus);

BOOL SysGetBluetoothPower(LPDWORD lpdwPowerStatus);

BOOL SysGetBluetoothPHYAddress(LPTSTR lpszPhyAddr);


//=====================================
//=       Boot Controls               =
//=====================================

int SysGetNumberOfBootProgram(DWORD dwBootMode);

BOOL SysRemoveAllBootProgram(DWORD dwBootMode);

BOOL SysGetBootProgram(DWORD dwBootMode,int dwLoadPriority,LPTSTR szProgramFile);

BOOL SysSetBootProgram(DWORD dwBootMode,int dwLoadPriority,LPTSTR szProgramFile);


//=====================================
//=       Vibrator Controls           =
//=====================================
BOOL SysSetVibrator(DWORD dwTimeMilliSecond);

BOOL SysStopVibrator(void);

//=====================================
//=       Touch Panel Controls        =
//=====================================

BOOL SysSetTouchPanelState(BOOL dwEnableStatus);

BOOL SysGetTouchPanelState(PBOOL lpdwEnableStatus);

//=====================================
//=       System Controls             =
//=====================================

BOOL SysGetSuspendTime(DWORD dwPowerMode,LPDWORD lpdwSuspendTime);

BOOL SysSetSuspendTime(DWORD dwPowerMode,DWORD dwSuspendTime);

BOOL SysSoftReset(void);

BOOL SysPowerDown (DWORD dwOnMode);

BOOL SysSetWakeSources(DWORD SourceFlags);

BOOL SysGetWakeSources(LPDWORD lpFlags);

BOOL SysGetPowerDownDisableMode(PBOOL pbDisableMode);

BOOL SysSetPowerDownDisableMode(BOOL bDisableMode);



BOOL SysGetACLineState(PBOOL lpACState);

BOOL SysGetMainBatteryState(PBYTE lpPowerLevel,PBOOL lpChargeState);

BOOL SysGetMainBatteryLifePercent(PWORD pPowerpercent,PBOOL lpChargeState);
	
BOOL SysGetBackupBatteryState(PBYTE lpPowerLevel,PBOOL lpChargeState);

BOOL SysLaunchCPLProgram(BYTE dwCPLProgram);

//=====================================
//=       LED Controls                =
//=====================================

BOOL SysSetLED(DWORD dwColor, BOOL On);


#ifdef __cplusplus
}
#endif

#endif
